/*
 * Copyright (C) 2023 iopsys Software Solutions AB
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2.1
 * as published by the Free Software Foundation
 *
 *	  Author: Suvendhu Hansa <suvendhu.hansa@iopsys.eu>
 *
 */

#ifndef __HELPER_H
#define __HELPER_H

#include <syslog.h>
#include <libubox/blobmsg.h>
#include <libubox/blobmsg_json.h>

void print_log(int severity, const char *format, ...);

#define PRINT_DEBUG(fmt, args...) \
	print_log(LOG_DEBUG, "[%s:%d]"fmt, __func__, __LINE__, ##args)

#define PRINT_INFO(fmt, args...) \
	print_log(LOG_INFO, "[%s:%d] " fmt, __func__, __LINE__, ##args)

#define PRINT_ERR(fmt, args...) \
	print_log(LOG_ERR, "[%s:%d] " fmt, __func__, __LINE__, ##args)

void get_current_status(const char *obj, const char *sec, struct blob_buf *bb);
void get_current_stats(const char *obj, const char *sec, struct blob_buf *bb);
void start_sync_timer(int seconds);
void timemngr_schedule_sync(struct uloop_timeout *timeout __attribute__((unused)));

#endif
